==> mteb-1.38.44.tar.gz: mteb-1.38.44/mteb/tasks/Retrieval/__init__.py <==
from __future__ import annotations

from .ara.SadeemQuestionRetrieval import *
from .code.AppsRetrieval import *
from .code.CodeEditSearchRetrieval import *
from .code.CodeFeedbackMTRetrieval import *
from .code.CodeFeedbackSTRetrieval import *
from .code.CodeRAG import *
from .code.CodeSearchNetCCRetrieval import *
from .code.CodeSearchNetRetrieval import *
from .code.CodeTransOceanContestRetrieval import *
from .code.CodeTransOceanDLRetrieval import *
from .code.COIRCodeSearchNetRetrieval import *
from .code.CosQARetrieval import *
from .code.DS1000Retrieval import *
from .code.FreshStackRetrieval import *
from .code.HumanEvalRetrieval import *
from .code.MBPPRetrieval import *
from .code.StackOverflowQARetrieval import *
from .code.SyntheticText2SqlRetrieval import *
from .code.WikiSQLRetrieval import *
from .dan.DanFeverRetrieval import *
from .dan.TV2Nordretrieval import *
from .dan.TwitterHjerneRetrieval import *
from .deu.GerDaLIRRetrieval import *
from .deu.GerDaLIRSmallRetrieval import *
from .deu.GermanDPRRetrieval import *
from .deu.GermanGovServiceRetrieval import *
from .deu.GermanQuADRetrieval import *
from .deu.LegalQuADRetrieval import *
from .ell.GreekCivicsQA import *
from .eng.AILACasedocsRetrieval import *
from .eng.AILAStatutesRetrieval import *
from .eng.AlphaNLIRetrieval import *
from .eng.ARCChallengeRetrieval import *
from .eng.ArguAnaRetrieval import *
from .eng.BarExamQARetrieval import *
from .eng.BillSumCARetrieval import *
from .eng.BillSumUSRetrieval import *
from .eng.BrightRetrieval import *
from .eng.BuiltBenchRetrieval import *
from .eng.ChatDoctorRetrieval import *
from .eng.ChemHotpotQARetrieval import *
from .eng.ChemNQRetrieval import *
from .eng.ClimateFEVERRetrieval import *
from .eng.CQADupstackAndroidRetrieval import *
from .eng.CQADupstackEnglishRetrieval import *
from .eng.CQADupstackGamingRetrieval import *
from .eng.CQADupstackGisRetrieval import *
from .eng.CQADupstackMathematicaRetrieval import *
from .eng.CQADupstackPhysicsRetrieval import *
from .eng.CQADupstackProgrammersRetrieval import *
from .eng.CQADupstackStatsRetrieval import *
from .eng.CQADupstackTexRetrieval import *
from .eng.CQADupstackUnixRetrieval import *
from .eng.CQADupstackWebmastersRetrieval import *
from .eng.CQADupstackWordpressRetrieval import *
from .eng.DBPediaRetrieval import *
from .eng.FaithDialRetrieval import *
from .eng.FeedbackQARetrieval import *
from .eng.FEVERRetrieval import *
from .eng.FinanceBenchRetrieval import *
from .eng.FinQARetrieval import *
from .eng.FiQA2018Retrieval import *
from .eng.GovReportRetrieval import *
from .eng.HagridRetrieval import *
from .eng.HC3FinanceRetrieval import *
from .eng.HellaSwagRetrieval import *
from .eng.HotpotQARetrieval import *
from .eng.LegalBenchConsumerContractsQARetrieval import *
from .eng.LegalBenchCorporateLobbyingRetrieval import *
from .eng.LegalSummarizationRetrieval import *
from .eng.LEMBNarrativeQARetrieval import *
from .eng.LEMBNeedleRetrieval import *
from .eng.LEMBPasskeyRetrieval import *
from .eng.LEMBQMSumRetrieval import *
from .eng.LEMBSummScreenFDRetrieval import *
from .eng.LEMBWikimQARetrieval import *
from .eng.LitSearchRetrieval import *
from .eng.MedicalQARetrieval import *
from .eng.MLQuestions import *
from .eng.MSMARCORetrieval import *
from .eng.MSMARCOv2Retrieval import *
from .eng.NanoArguAnaRetrieval import *
from .eng.NanoClimateFeverRetrieval import *
from .eng.NanoDBPediaRetrieval import *
from .eng.NanoFEVERRetrieval import *
from .eng.NanoFiQA2018Retrieval import *
from .eng.NanoHotpotQARetrieval import *
from .eng.NanoMSMARCORetrieval import *
from .eng.NanoNFCorpusRetrieval import *
from .eng.NanoNQRetrieval import *
from .eng.NanoQuoraRetrieval import *
from .eng.NanoSCIDOCSRetrieval import *
from .eng.NanoSciFactRetrieval import *
from .eng.NanoTouche2020Retrieval import *
from .eng.NarrativeQARetrieval import *
from .eng.NFCorpusRetrieval import *
from .eng.NQRetrieval import *
from .eng.PiqaRetrieval import *
from .eng.QuailRetrieval import *
from .eng.QuoraRetrieval import *
from .eng.R2MEDRetrieval import *
from .eng.RARbCodeRetrieval import *
from .eng.RARbMathRetrieval import *
from .eng.SCIDOCSRetrieval import *
from .eng.SciFactRetrieval import *
from .eng.SiqaRetrieval import *
from .eng.SpartQARetrieval import *
from .eng.TempReasonL1Retrieval import *
from .eng.TempReasonL2ContextRetrieval import *
from .eng.TempReasonL2FactRetrieval import *
from .eng.TempReasonL2PureRetrieval import *
from .eng.TempReasonL3ContextRetrieval import *
from .eng.TempReasonL3FactRetrieval import *
from .eng.TempReasonL3PureRetrieval import *
from .eng.TopiOCQARetrieval import *
from .eng.Touche2020Retrieval import *
from .eng.TRECCOVIDRetrieval import *
from .eng.WinoGrandeRetrieval import *
from .est.estqa import *
from .fas.BEIRFa import *
from .fas.FaMTEBRetrieval import *
from .fra.AlloprofRetrieval import *
from .fra.BSARDRetrieval import *
from .fra.FQuADRetrieval import *
from .fra.SyntecRetrieval import *
from .hun.HunSum2 import *
from .jpn.JaCWIRRetrieval import *
from .jpn.JaGovFaqsRetrieval import *
from .jpn.JaqketRetrieval import *
from .jpn.JaQuADRetrieval import *
from .jpn.NLPJournalAbsArticleRetrieval import *
from .jpn.NLPJournalAbsIntroRetrieval import *
from .jpn.NLPJournalTitleAbsRetrieval import *
from .jpn.NLPJournalTitleIntroRetrieval import *
from .kat.GeorgianFAQRetrieval import *
from .kor.AutoRAGRetrieval import *
from .kor.KoStrategyQA import *
from .multilingual.BelebeleRetrieval import *
from .multilingual.CrossLingualSemanticDiscriminationWMT19 import *
from .multilingual.CrossLingualSemanticDiscriminationWMT21 import *
from .multilingual.CUREv1Retrieval import *
from .multilingual.IndicQARetrieval import *
from .multilingual.MintakaRetrieval import *
from .multilingual.MIRACLRetrieval import *
from .multilingual.MKQARetrieval import *
from .multilingual.MLQARetrieval import *
from .multilingual.MrTidyRetrieval import *
from .multilingual.MultiLongDocRetrieval import *
from .multilingual.NeuCLIR2022Retrieval import *
from .multilingual.NeuCLIR2023Retrieval import *
from .multilingual.PublicHealthQARetrieval import *
from .multilingual.RuSciBenchRetrieval import *
from .multilingual.StatcanDialogueDatasetRetrieval import *
from .multilingual.WebFAQRetrieval import *
from .multilingual.WikipediaRetrievalMultilingual import *
from .multilingual.XMarketRetrieval import *
from .multilingual.XPQARetrieval import *
from .multilingual.XQuADRetrieval import *
from .nld.ArguAnaNLRetrieval import *
from .nld.ClimateFEVERNLRetrieval import *
from .nld.CQADupstackAndroidNLRetrieval import *
from .nld.CQADupstackEnglishNLRetrieval import *
from .nld.CQADupstackGamingNLRetrieval import *
from .nld.CQADupstackGisNLRetrieval import *
from .nld.CQADupstackMathematicaNLRetrieval import *
from .nld.CQADupstackPhysicsNLRetrieval import *
from .nld.CQADupstackProgrammersNLRetrieval import *
from .nld.CQADupstackStatsNLRetrieval import *
from .nld.CQADupstackTexNLRetrieval import *
from .nld.CQADupstackUnixNLRetrieval import *
from .nld.CQADupstackWebmastersNLRetrieval import *
from .nld.CQADupstackWordpressNLRetrieval import *
from .nld.DBPediaNLRetrieval import *
from .nld.FEVERNLRetrieval import *
from .nld.FiQA2018NLRetrieval import *
from .nld.HotpotQANLRetrieval import *
from .nld.MMARCONLRetrieval import *
from .nld.NFCorpusNLRetrieval import *
from .nld.NQNLRetrieval import *
from .nld.QuoraNLRetrieval import *
from .nld.SCIDOCSNLRetrieval import *
from .nld.SciFactNLRetrieval import *
from .nld.Touche2020NLRetrieval import *
from .nld.TRECCOVIDNLRetrieval import *
from .nob.norquad import *
from .nob.snl_retrieval import *
from .pol.ArguAnaPLRetrieval import *
from .pol.DBPediaPLRetrieval import *
from .pol.FiQAPLRetrieval import *
from .pol.HotpotQAPLRetrieval import *
from .pol.MSMARCOPLRetrieval import *
from .pol.NFCorpusPLRetrieval import *
from .pol.NQPLRetrieval import *
from .pol.QuoraPLRetrieval import *
from .pol.SCIDOCSPLRetrieval import *
from .pol.SciFactPLRetrieval import *
from .pol.TRECCOVIDPLRetrieval import *
from .rus.RiaNewsRetrieval import *
from .rus.RuBQRetrieval import *
from .slk.SKQuadRetrieval import *
from .slk.SlovakSumRetrieval import *
from .spa.SpanishPassageRetrievalS2P import *
from .spa.SpanishPassageRetrievalS2S import *
from .swe.SwednRetrieval import *
from .swe.SweFaqRetrieval import *
from .tur.TurHistQuad import *
from .vie.ArguAnaVNRetrieval import *
from .vie.ClimateFEVERVNRetrieval import *
from .vie.CQADupstackAndroidVNRetrieval import *
from .vie.CQADupstackGisVNRetrieval import *
from .vie.CQADupstackMathematicaVNRetrieval import *
from .vie.CQADupstackPhysicsVNRetrieval import *
from .vie.CQADupstackProgrammersVNRetrieval import *
from .vie.CQADupstackStatsVNRetrieval import *
from .vie.CQADupstackTexVNRetrieval import *
from .vie.CQADupstackUnixVNRetrieval import *
from .vie.CQADupstackWebmastersVNRetrieval import *
from .vie.CQADupstackWordpressVNRetrieval import *
from .vie.DBPediaVNRetrieval import *
from .vie.FEVERVNRetrieval import *
from .vie.FiQA2018VNRetrieval import *
from .vie.GreenNodeTableMarkdownRetrieval import *
from .vie.HotpotQAVNRetrieval import *
from .vie.MSMARCOVNRetrieval import *
from .vie.NFCorpusVNRetrieval import *
from .vie.NQVNRetrieval import *
from .vie.QuoraVNRetrieval import *
from .vie.SCIDOCSVNRetrieval import *
from .vie.SciFactVNRetrieval import *
from .vie.Touche2020VNRetrieval import *
from .vie.TRECCOVIDVNRetrieval import *
from .vie.VieQuADRetrieval import *
from .vie.ZacLegalTextRetrieval import *
from .zho.CMTEBRetrieval import *
from .zho.LeCaRDv2Retrieval import *

==> mteb-1.38.60.tar.gz: mteb-1.38.60/mteb/tasks/Retrieval/__init__.py <==
from __future__ import annotations

from .ara.SadeemQuestionRetrieval import *
from .code.AppsRetrieval import *
from .code.Code1Retrieval import *
from .code.CodeEditSearchRetrieval import *
from .code.CodeFeedbackMTRetrieval import *
from .code.CodeFeedbackSTRetrieval import *
from .code.CodeRAG import *
from .code.CodeSearchNetCCRetrieval import *
from .code.CodeSearchNetRetrieval import *
from .code.CodeTransOceanContestRetrieval import *
from .code.CodeTransOceanDLRetrieval import *
from .code.COIRCodeSearchNetRetrieval import *
from .code.CosQARetrieval import *
from .code.DS1000Retrieval import *
from .code.FreshStackRetrieval import *
from .code.HumanEvalRetrieval import *
from .code.JapaneseCode1Retrieval import *
from .code.MBPPRetrieval import *
from .code.StackOverflowQARetrieval import *
from .code.SyntheticText2SqlRetrieval import *
from .code.WikiSQLRetrieval import *
from .dan.DanFeverRetrieval import *
from .dan.TV2Nordretrieval import *
from .dan.TwitterHjerneRetrieval import *
from .deu.GerDaLIRRetrieval import *
from .deu.GerDaLIRSmallRetrieval import *
from .deu.German1Retrieval import *
from .deu.GermanDPRRetrieval import *
from .deu.GermanGovServiceRetrieval import *
from .deu.GermanHealthcare1Retrieval import *
from .deu.GermanLegal1Retrieval import *
from .deu.GermanQuADRetrieval import *
from .deu.LegalQuADRetrieval import *
from .ell.GreekCivicsQA import *
from .eng.AILACasedocsRetrieval import *
from .eng.AILAStatutesRetrieval import *
from .eng.AlphaNLIRetrieval import *
from .eng.ARCChallengeRetrieval import *
from .eng.ArguAnaRetrieval import *
from .eng.BarExamQARetrieval import *
from .eng.BillSumCARetrieval import *
from .eng.BillSumUSRetrieval import *
from .eng.BrightRetrieval import *
from .eng.BuiltBenchRetrieval import *
from .eng.ChatDoctorRetrieval import *
from .eng.ChemHotpotQARetrieval import *
from .eng.ChemNQRetrieval import *
from .eng.ClimateFEVERRetrieval import *
from .eng.CQADupstackAndroidRetrieval import *
from .eng.CQADupstackEnglishRetrieval import *
from .eng.CQADupstackGamingRetrieval import *
from .eng.CQADupstackGisRetrieval import *
from .eng.CQADupstackMathematicaRetrieval import *
from .eng.CQADupstackPhysicsRetrieval import *
from .eng.CQADupstackProgrammersRetrieval import *
from .eng.CQADupstackStatsRetrieval import *
from .eng.CQADupstackTexRetrieval import *
from .eng.CQADupstackUnixRetrieval import *
from .eng.CQADupstackWebmastersRetrieval import *
from .eng.CQADupstackWordpressRetrieval import *
from .eng.DAPFAMPatentRetrieval import *
from .eng.DBPediaRetrieval import *
from .eng.EnglishFinance1Retrieval import *
from .eng.EnglishFinance2Retrieval import *
from .eng.EnglishFinance3Retrieval import *
from .eng.EnglishFinance4Retrieval import *
from .eng.EnglishHealthcare1Retrieval import *
from .eng.FaithDialRetrieval import *
from .eng.FeedbackQARetrieval import *
from .eng.FEVERRetrieval import *
from .eng.FinanceBenchRetrieval import *
from .eng.FinQARetrieval import *
from .eng.FiQA2018Retrieval import *
from .eng.GovReportRetrieval import *
from .eng.HagridRetrieval import *
from .eng.HC3FinanceRetrieval import *
from .eng.HellaSwagRetrieval import *
from .eng.HotpotQARetrieval import *
from .eng.LegalBenchConsumerContractsQARetrieval import *
from .eng.LegalBenchCorporateLobbyingRetrieval import *
from .eng.LegalSummarizationRetrieval import *
from .eng.LEMBNarrativeQARetrieval import *
from .eng.LEMBNeedleRetrieval import *
from .eng.LEMBPasskeyRetrieval import *
from .eng.LEMBQMSumRetrieval import *
from .eng.LEMBSummScreenFDRetrieval import *
from .eng.LEMBWikimQARetrieval import *
from .eng.LitSearchRetrieval import *
from .eng.MedicalQARetrieval import *
from .eng.MLQuestions import *
from .eng.MSMARCORetrieval import *
from .eng.MSMARCOv2Retrieval import *
from .eng.NanoArguAnaRetrieval import *
from .eng.NanoClimateFeverRetrieval import *
from .eng.NanoDBPediaRetrieval import *
from .eng.NanoFEVERRetrieval import *
from .eng.NanoFiQA2018Retrieval import *
from .eng.NanoHotpotQARetrieval import *
from .eng.NanoMSMARCORetrieval import *
from .eng.NanoNFCorpusRetrieval import *
from .eng.NanoNQRetrieval import *
from .eng.NanoQuoraRetrieval import *
from .eng.NanoSCIDOCSRetrieval import *
from .eng.NanoSciFactRetrieval import *
from .eng.NanoTouche2020Retrieval import *
from .eng.NarrativeQARetrieval import *
from .eng.NFCorpusRetrieval import *
from .eng.NQRetrieval import *
from .eng.PiqaRetrieval import *
from .eng.QuailRetrieval import *
from .eng.QuoraRetrieval import *
from .eng.R2MEDRetrieval import *
from .eng.RARbCodeRetrieval import *
from .eng.RARbMathRetrieval import *
from .eng.SCIDOCSRetrieval import *
from .eng.SciFactRetrieval import *
from .eng.SiqaRetrieval import *
from .eng.SpartQARetrieval import *
from .eng.TempReasonL1Retrieval import *
from .eng.TempReasonL2ContextRetrieval import *
from .eng.TempReasonL2FactRetrieval import *
from .eng.TempReasonL2PureRetrieval import *
from .eng.TempReasonL3ContextRetrieval import *
from .eng.TempReasonL3FactRetrieval import *
from .eng.TempReasonL3PureRetrieval import *
from .eng.TopiOCQARetrieval import *
from .eng.Touche2020Retrieval import *
from .eng.TRECCOVIDRetrieval import *
from .eng.WinoGrandeRetrieval import *
from .est.estqa import *
from .fas.BEIRFa import *
from .fas.FaMTEBRetrieval import *
from .fra.AlloprofRetrieval import *
from .fra.BSARDRetrieval import *
from .fra.FQuADRetrieval import *
from .fra.French1Retrieval import *
from .fra.FrenchLegal1Retrieval import *
from .fra.SyntecRetrieval import *
from .hun.HunSum2 import *
from .jpn.JaCWIRRetrieval import *
from .jpn.JaGovFaqsRetrieval import *
from .jpn.JapaneseLegal1Retrieval import *
from .jpn.JaqketRetrieval import *
from .jpn.JaQuADRetrieval import *
from .jpn.NLPJournalAbsArticleRetrieval import *
from .jpn.NLPJournalAbsIntroRetrieval import *
from .jpn.NLPJournalTitleAbsRetrieval import *
from .jpn.NLPJournalTitleIntroRetrieval import *
from .kat.GeorgianFAQRetrieval import *
from .kor.AutoRAGRetrieval import *
from .kor.KoStrategyQA import *
from .multilingual.BelebeleRetrieval import *
from .multilingual.CrossLingualSemanticDiscriminationWMT19 import *
from .multilingual.CrossLingualSemanticDiscriminationWMT21 import *
from .multilingual.CUREv1Retrieval import *
from .multilingual.IndicQARetrieval import *
from .multilingual.MintakaRetrieval import *
from .multilingual.MIRACLRetrieval import *
from .multilingual.MKQARetrieval import *
from .multilingual.MLQARetrieval import *
from .multilingual.MrTidyRetrieval import *
from .multilingual.MultiLongDocRetrieval import *
from .multilingual.NeuCLIR2022Retrieval import *
from .multilingual.NeuCLIR2023Retrieval import *
from .multilingual.PublicHealthQARetrieval import *
from .multilingual.RuSciBenchRetrieval import *
from .multilingual.StatcanDialogueDatasetRetrieval import *
from .multilingual.WebFAQRetrieval import *
from .multilingual.WikipediaRetrievalMultilingual import *
from .multilingual.XMarketRetrieval import *
from .multilingual.XPQARetrieval import *
from .multilingual.XQuADRetrieval import *
from .nld.ArguAnaNLRetrieval import *
from .nld.ClimateFEVERNLRetrieval import *
from .nld.CQADupstackAndroidNLRetrieval import *
from .nld.CQADupstackEnglishNLRetrieval import *
from .nld.CQADupstackGamingNLRetrieval import *
from .nld.CQADupstackGisNLRetrieval import *
from .nld.CQADupstackMathematicaNLRetrieval import *
from .nld.CQADupstackPhysicsNLRetrieval import *
from .nld.CQADupstackProgrammersNLRetrieval import *
from .nld.CQADupstackStatsNLRetrieval import *
from .nld.CQADupstackTexNLRetrieval import *
from .nld.CQADupstackUnixNLRetrieval import *
from .nld.CQADupstackWebmastersNLRetrieval import *
from .nld.CQADupstackWordpressNLRetrieval import *
from .nld.DBPediaNLRetrieval import *
from .nld.FEVERNLRetrieval import *
from .nld.FiQA2018NLRetrieval import *
from .nld.HotpotQANLRetrieval import *
from .nld.MMARCONLRetrieval import *
from .nld.NFCorpusNLRetrieval import *
from .nld.NQNLRetrieval import *
from .nld.QuoraNLRetrieval import *
from .nld.SCIDOCSNLRetrieval import *
from .nld.SciFactNLRetrieval import *
from .nld.Touche2020NLRetrieval import *
from .nld.TRECCOVIDNLRetrieval import *
from .nob.norquad import *
from .nob.snl_retrieval import *
from .pol.ArguAnaPLRetrieval import *
from .pol.DBPediaPLRetrieval import *
from .pol.FiQAPLRetrieval import *
from .pol.HotpotQAPLRetrieval import *
from .pol.MSMARCOPLRetrieval import *
from .pol.NFCorpusPLRetrieval import *
from .pol.NQPLRetrieval import *
from .pol.QuoraPLRetrieval import *
from .pol.SCIDOCSPLRetrieval import *
from .pol.SciFactPLRetrieval import *
from .pol.TRECCOVIDPLRetrieval import *
from .rus.RiaNewsRetrieval import *
from .rus.RuBQRetrieval import *
from .slk.SKQuadRetrieval import *
from .slk.SlovakSumRetrieval import *
from .spa.SpanishPassageRetrievalS2P import *
from .spa.SpanishPassageRetrievalS2S import *
from .swe.SwednRetrieval import *
from .swe.SweFaqRetrieval import *
from .tur.TurHistQuad import *
from .vie.ArguAnaVNRetrieval import *
from .vie.ClimateFEVERVNRetrieval import *
from .vie.CQADupstackAndroidVNRetrieval import *
from .vie.CQADupstackGisVNRetrieval import *
from .vie.CQADupstackMathematicaVNRetrieval import *
from .vie.CQADupstackPhysicsVNRetrieval import *
from .vie.CQADupstackProgrammersVNRetrieval import *
from .vie.CQADupstackStatsVNRetrieval import *
from .vie.CQADupstackTexVNRetrieval import *
from .vie.CQADupstackUnixVNRetrieval import *
from .vie.CQADupstackWebmastersVNRetrieval import *
from .vie.CQADupstackWordpressVNRetrieval import *
from .vie.DBPediaVNRetrieval import *
from .vie.FEVERVNRetrieval import *
from .vie.FiQA2018VNRetrieval import *
from .vie.GreenNodeTableMarkdownRetrieval import *
from .vie.HotpotQAVNRetrieval import *
from .vie.MSMARCOVNRetrieval import *
from .vie.NFCorpusVNRetrieval import *
from .vie.NQVNRetrieval import *
from .vie.QuoraVNRetrieval import *
from .vie.SCIDOCSVNRetrieval import *
from .vie.SciFactVNRetrieval import *
from .vie.Touche2020VNRetrieval import *
from .vie.TRECCOVIDVNRetrieval import *
from .vie.VieQuADRetrieval import *
from .vie.ZacLegalTextRetrieval import *
from .zho.CMTEBRetrieval import *
from .zho.LeCaRDv2Retrieval import *
